Rule

Enum Rule 

pub enum Rule {
Show 312 variants EOI, WHITESPACE, block_comment, line_comment, query, semicolon, statement, schema_command, create_index_command, index_kind, index_name_spec, if_not_exists, index_pattern, indexed_node_pattern, indexed_rel_pattern, fulltext_node_pattern, fulltext_rel_pattern, lookup_node_pattern, lookup_rel_pattern, index_var, index_property_spec, index_property_list, index_property_each, index_property, index_token_lookup, index_token_func, index_options, show_indexes_command, show_index_filter, show_pipeline, show_yield, show_return, drop_index_command, if_exists, create_constraint_command, constraint_name_spec, constraint_pattern, constraint_node_pattern, constraint_rel_pattern, constraint_property_spec, constraint_property_group, constraint_property, constraint_requirement, type_predicate, constraint_type_expr, constraint_type_term, constraint_vector_type, vector_coord_type, constraint_list_type, constraint_scalar_type, drop_constraint_command, show_constraints_command, regular_query, union_clause, single_query, multi_part_query, query_part, single_part_query, call_subquery_clause, reading_clause, updating_clause, match_clause, unwind_clause, create_clause, merge_clause, merge_action, delete_clause, set_clause, foreach_clause, set_item, property_set_target, remove_clause, remove_item, in_query_call, standalone_call, call_subquery, yield_clause, yield_items, yield_item, with_clause, where_clause, return_clause, projection_body, projection_items, projection_item, star, order_clause, sort_item, skip_clause, limit_clause, pattern, pattern_part, anonymous_pattern_part, shortest_path_pattern, pattern_element, pattern_element_chain, node_pattern, relationship_pattern, relationship_detail, relationship_types, node_labels, node_label_set, node_label, range_literal, properties, expression, case_expression, simple_case_expression, generic_case_expression, or_expression, xor_expression, and_expression, not_expression, comparison_expression, comparison_tail, regex_match, comparison_op, add_expression, mul_expression, pow_expression, unary_expression, postfix_expression, postfix_op, type_cast_postfix, property_lookup, map_projection_postfix, map_projection_selector, atom, exists_subquery, count_subquery, label_predicate, reduce_expression, REDUCE, list_predicate, parenthesized_expression, type_cast_expression, cast_call_expression, try_cast_call_expression, literal_type_expr, literal_vector_type, literal_list_type, literal_named_type, function_invocation, procedure_invocation, procedure_name, function_name, namespace, literal, boolean_literal, null_literal, list_literal, pattern_comprehension, list_comprehension, map_literal, parameter, number_literal, integer_literal, double_literal, hex_integer, octal_integer, decimal_integer, exponent_decimal_real, regular_decimal_real, string_literal, string_double, string_single, variable, property_key_name, label_name, rel_type_name, schema_name, symbolic_name, unescaped_symbolic_name, escaped_symbolic_name, ident_start, ident_part, reserved_word, lparen, rparen, lbrack, rbrack, lbrace, rbrace, comma, dot, pipe, colon, colon_sep, double_colon, dotdot, eq, plus_eq, ne, lt, gt, le, ge, add, sub, mul, div, modulo, pow, dash, left_arrow, right_arrow, ALL, ASC, ASCENDING, BY, CALL, CREATE, DELETE, DESC, DESCENDING, DETACH, DISTINCT, EXISTS, LIMIT, MATCH, MERGE, ON, OPTIONAL, ORDER, REMOVE, RETURN, SET, SKIP, WHERE, WITH, YIELD, UNION, UNWIND, FOREACH, AND, AS, CONTAINS, ENDS, IN, IS, NOT, OR, STARTS, XOR, FALSE, TRUE, NULL, CASE, WHEN, THEN, ELSE, END, COUNT, CAST, TRY_CAST, ANY_, NONE, SINGLE, index_or_slice, slice_op, slice_dots, index_op, SHORTEST_PATH, ALL_SHORTEST_PATHS, INDEX, INDEXES, RANGE, TEXT, POINT, LOOKUP, FULLTEXT, FOR, IF, EACH, OPTIONS, SHOW, DROP_KW, LABELS_FN, TYPE_FN, CONSTRAINT, CONSTRAINTS, REQUIRE, UNIQUE, NODE, KEY, RELATIONSHIP, LOCAL_DATETIME, ZONED_DATETIME, LOCAL_TIME, ZONED_TIME, BOOLEAN, STRING, INTEGER, FLOAT, DATE, DURATION, LIST, VECTOR, MAP_T, ANY_T, INTEGER8, INTEGER16, INTEGER32, INTEGER64, INT8, INT16, INT32, INT64, INT, FLOAT32, FLOAT64, STAR,
}

Variants



EOI

End-of-input



WHITESPACE



block_comment



line_comment



query



semicolon



statement



schema_command



create_index_command



index_kind



index_name_spec



if_not_exists



index_pattern



indexed_node_pattern



indexed_rel_pattern



fulltext_node_pattern



fulltext_rel_pattern



lookup_node_pattern



lookup_rel_pattern



index_var



index_property_spec



index_property_list



index_property_each



index_property



index_token_lookup



index_token_func



index_options



show_indexes_command



show_index_filter



show_pipeline



show_yield



show_return



drop_index_command



if_exists



create_constraint_command



constraint_name_spec



constraint_pattern



constraint_node_pattern



constraint_rel_pattern



constraint_property_spec



constraint_property_group



constraint_property



constraint_requirement



type_predicate



constraint_type_expr



constraint_type_term



constraint_vector_type



vector_coord_type



constraint_list_type



constraint_scalar_type



drop_constraint_command



show_constraints_command



regular_query



union_clause



single_query



multi_part_query



query_part



single_part_query



call_subquery_clause



reading_clause



updating_clause



match_clause



unwind_clause



create_clause



merge_clause



merge_action



delete_clause



set_clause



foreach_clause



set_item



property_set_target



remove_clause



remove_item



in_query_call



standalone_call



call_subquery



yield_clause



yield_items



yield_item



with_clause



where_clause



return_clause



projection_body



projection_items



projection_item



star



order_clause



sort_item



skip_clause



limit_clause



pattern



pattern_part



anonymous_pattern_part



shortest_path_pattern



pattern_element



pattern_element_chain



node_pattern



relationship_pattern



relationship_detail



relationship_types



node_labels



node_label_set



node_label



range_literal



properties



expression



case_expression



simple_case_expression



generic_case_expression



or_expression



xor_expression



and_expression



not_expression



comparison_expression



comparison_tail



regex_match



comparison_op



add_expression



mul_expression



pow_expression



unary_expression



postfix_expression



postfix_op



type_cast_postfix



property_lookup



map_projection_postfix



map_projection_selector



atom



exists_subquery



count_subquery



label_predicate



reduce_expression



REDUCE



list_predicate



parenthesized_expression



type_cast_expression



cast_call_expression



try_cast_call_expression



literal_type_expr



literal_vector_type



literal_list_type



literal_named_type



function_invocation



procedure_invocation



procedure_name



function_name



namespace



literal



boolean_literal



null_literal



list_literal



pattern_comprehension



list_comprehension



map_literal



parameter



number_literal



integer_literal



double_literal



hex_integer



octal_integer



decimal_integer



exponent_decimal_real



regular_decimal_real



string_literal



string_double



string_single



variable



property_key_name



label_name



rel_type_name



schema_name



symbolic_name



unescaped_symbolic_name



escaped_symbolic_name



ident_start



ident_part



reserved_word



lparen



rparen



lbrack



rbrack



lbrace



rbrace



comma



dot



pipe



colon



colon_sep



double_colon



dotdot



eq



plus_eq



ne



lt



gt



le



ge



add



sub



mul



div



modulo



pow



dash



left_arrow



right_arrow



ALL



ASC



ASCENDING



BY



CALL



CREATE



DELETE



DESC



DESCENDING



DETACH



DISTINCT



EXISTS



LIMIT



MATCH



MERGE



ON



OPTIONAL



ORDER



REMOVE



RETURN



SET



SKIP



WHERE



WITH



YIELD



UNION



UNWIND



FOREACH



AND



AS



CONTAINS



ENDS



IN



IS



NOT



OR



STARTS



XOR



FALSE



TRUE



NULL



CASE



WHEN



THEN



ELSE



END



COUNT



CAST



TRY_CAST



ANY_



NONE



SINGLE



index_or_slice



slice_op



slice_dots



index_op



SHORTEST_PATH



ALL_SHORTEST_PATHS



INDEX



INDEXES



RANGE



TEXT



POINT



LOOKUP



FULLTEXT



FOR



IF



EACH



OPTIONS



SHOW



DROP_KW



LABELS_FN



TYPE_FN



CONSTRAINT



CONSTRAINTS



REQUIRE



UNIQUE



NODE



KEY



RELATIONSHIP



LOCAL_DATETIME



ZONED_DATETIME



LOCAL_TIME



ZONED_TIME



BOOLEAN



STRING



INTEGER



FLOAT



DATE



DURATION



LIST



VECTOR



MAP_T



ANY_T



INTEGER8



INTEGER16



INTEGER32



INTEGER64



INT8



INT16



INT32



INT64



INT



FLOAT32



FLOAT64



STAR

Implementations

Source

impl Rule

pub fn all_rules() -> &'static [Rule]