Rule

Enum Rule 

pub enum Rule {
Show 203 variants EOI, WHITESPACE, block_comment, line_comment, query, semicolon, statement, regular_query, union_clause, single_query, multi_part_query, query_part, single_part_query, reading_clause, updating_clause, match_clause, unwind_clause, create_clause, merge_clause, merge_action, delete_clause, set_clause, set_item, property_set_target, remove_clause, remove_item, in_query_call, standalone_call, yield_clause, yield_items, yield_item, with_clause, where_clause, return_clause, projection_body, projection_items, projection_item, star, order_clause, sort_item, skip_clause, limit_clause, pattern, pattern_part, anonymous_pattern_part, shortest_path_pattern, pattern_element, pattern_element_chain, node_pattern, relationship_pattern, relationship_detail, relationship_types, node_labels, node_label_set, node_label, range_literal, properties, expression, case_expression, simple_case_expression, generic_case_expression, or_expression, xor_expression, and_expression, not_expression, comparison_expression, comparison_tail, regex_match, comparison_op, add_expression, mul_expression, pow_expression, unary_expression, postfix_expression, postfix_op, property_lookup, map_projection_postfix, map_projection_selector, atom, exists_subquery, reduce_expression, REDUCE, list_predicate, parenthesized_expression, function_invocation, procedure_invocation, procedure_name, function_name, namespace, literal, boolean_literal, null_literal, list_literal, pattern_comprehension, list_comprehension, map_literal, parameter, number_literal, integer_literal, double_literal, hex_integer, octal_integer, decimal_integer, exponent_decimal_real, regular_decimal_real, string_literal, string_double, string_single, variable, property_key_name, label_name, rel_type_name, schema_name, symbolic_name, unescaped_symbolic_name, escaped_symbolic_name, ident_start, ident_part, reserved_word, lparen, rparen, lbrack, rbrack, lbrace, rbrace, comma, dot, pipe, colon, colon_sep, dotdot, eq, plus_eq, ne, lt, gt, le, ge, add, sub, mul, div, modulo, pow, dash, left_arrow, right_arrow, ALL, ASC, ASCENDING, BY, CALL, CREATE, DELETE, DESC, DESCENDING, DETACH, DISTINCT, EXISTS, LIMIT, MATCH, MERGE, ON, OPTIONAL, ORDER, REMOVE, RETURN, SET, SKIP, WHERE, WITH, YIELD, UNION, UNWIND, AND, AS, CONTAINS, ENDS, IN, IS, NOT, OR, STARTS, XOR, FALSE, TRUE, NULL, CASE, WHEN, THEN, ELSE, END, COUNT, ANY_, NONE, SINGLE, index_or_slice, slice_op, slice_dots, index_op, SHORTEST_PATH, ALL_SHORTEST_PATHS, STAR,
}

Variants



EOI

End-of-input



WHITESPACE



block_comment



line_comment



query



semicolon



statement



regular_query



union_clause



single_query



multi_part_query



query_part



single_part_query



reading_clause



updating_clause



match_clause



unwind_clause



create_clause



merge_clause



merge_action



delete_clause



set_clause



set_item



property_set_target



remove_clause



remove_item



in_query_call



standalone_call



yield_clause



yield_items



yield_item



with_clause



where_clause



return_clause



projection_body



projection_items



projection_item



star



order_clause



sort_item



skip_clause



limit_clause



pattern



pattern_part



anonymous_pattern_part



shortest_path_pattern



pattern_element



pattern_element_chain



node_pattern



relationship_pattern



relationship_detail



relationship_types



node_labels



node_label_set



node_label



range_literal



properties



expression



case_expression



simple_case_expression



generic_case_expression



or_expression



xor_expression



and_expression



not_expression



comparison_expression



comparison_tail



regex_match



comparison_op



add_expression



mul_expression



pow_expression



unary_expression



postfix_expression



postfix_op



property_lookup



map_projection_postfix



map_projection_selector



atom



exists_subquery



reduce_expression



REDUCE



list_predicate



parenthesized_expression



function_invocation



procedure_invocation



procedure_name



function_name



namespace



literal



boolean_literal



null_literal



list_literal



pattern_comprehension



list_comprehension



map_literal



parameter



number_literal



integer_literal



double_literal



hex_integer



octal_integer



decimal_integer



exponent_decimal_real



regular_decimal_real



string_literal



string_double



string_single



variable



property_key_name



label_name



rel_type_name



schema_name



symbolic_name



unescaped_symbolic_name



escaped_symbolic_name



ident_start



ident_part



reserved_word



lparen



rparen



lbrack



rbrack



lbrace



rbrace



comma



dot



pipe



colon



colon_sep



dotdot



eq



plus_eq



ne



lt



gt



le



ge



add



sub



mul



div



modulo



pow



dash



left_arrow



right_arrow



ALL



ASC



ASCENDING



BY



CALL



CREATE



DELETE



DESC



DESCENDING



DETACH



DISTINCT



EXISTS



LIMIT



MATCH



MERGE



ON



OPTIONAL



ORDER



REMOVE



RETURN



SET



SKIP



WHERE



WITH



YIELD



UNION



UNWIND



AND



AS



CONTAINS



ENDS



IN



IS



NOT



OR



STARTS



XOR



FALSE



TRUE



NULL



CASE



WHEN



THEN



ELSE



END



COUNT



ANY_



NONE



SINGLE



index_or_slice



slice_op



slice_dots



index_op



SHORTEST_PATH



ALL_SHORTEST_PATHS



STAR

Implementations

Source

impl Rule

pub fn all_rules() -> &'static [Rule]